@@ -70,7 +70,7 @@ class UnexpectedError(StatusError):
     """Raised if the error was not caught"""
 
 
-class NoAuthFlow(Exception):
+class AuthFlowError(Exception):
     """Raised if no auth method available"""
 
 
@@ -80,3 +80,4 @@ class NoRefreshToken(Exception):
 
 class FileEncryptionError(Exception):
     """Raised if something is wrong with file encryption"""
+
