@@ -1,29 +1,32 @@
 import base64
+import hashlib
 import io
 import json
 import logging
 import re
-import uuid
 import secrets
-from datetime import datetime, timedelta
+import uuid
 from typing import Any, Callable, Dict, Optional, Tuple
 from urllib.parse import urlencode, parse_qs
 
-from bs4 import BeautifulSoup
-from PIL import Image
 import httpx
+from PIL import Image
+from bs4 import BeautifulSoup
 
 from .metadata import encrypt_metadata, meta_audible_app
 
 
 logger = logging.getLogger("audible.login")
 
-USER_AGENT = ("Mozilla/5.0 (iPhone; CPU iPhone OS 14_1 like Mac OS X) "
-              "AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148")
+USER_AGENT = (
+    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0 like Mac OS X) "
+    "AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148"
+)
 
 
 def default_captcha_callback(captcha_url: str) -> str:
     """Helper function for handling captcha."""
+
     captcha = httpx.get(captcha_url).content
     f = io.BytesIO(captcha)
     img = Image.open(f)
@@ -34,6 +37,7 @@ def default_captcha_callback(captcha_url: str) -> str:
 
 def default_otp_callback() -> str:
     """Helper function for handling 2-factor authentication."""
+
     guess = input("OTP Code: ")
     return str(guess).strip().lower()
 
@@ -43,18 +47,56 @@ def default_cvf_callback() -> str:
     
     Amazon sends a verify code via Mail or SMS.
     """
+
     guess = input("CVF Code: ")
     return str(guess).strip().lower()
 
 
 def default_approval_alert_callback() -> None:
     """Helper function for handling approval alerts."""
+
     print("Approval alert detected! Amazon sends you a mail.")
     input("Please press ENTER when you approve the notification.")
 
 
 def default_login_url_callback(url: str) -> str:
     """Helper function for login with external browsers."""
+
+    try:
+        from playwright.sync_api import sync_playwright
+        use_playwright = True
+    except ImportError:
+        use_playwright = False
+
+    if use_playwright:
+        with sync_playwright() as p:
+            iphone = p.devices["iPhone 12 Pro"]
+            browser = p.webkit.launch(headless=False)
+            context = browser.new_context(
+                **iphone
+            )
+            cookies = []
+            for name, value in build_init_cookies().items():
+                cookies.append(
+                    {
+                        "name": name,
+                        "value": value,
+                        "url": url
+                    }
+                )
+            context.add_cookies(cookies)
+            page = browser.new_page()
+            page.goto(url)
+
+            while True:
+                page.wait_for_timeout(600)
+                if "/ap/maplanding" in page.url:
+                    response_url = page.url
+                    break
+
+            browser.close()
+        return response_url
+
     print("Please copy the following url and insert it in a webbrowser of "
           "your choice:")
     print("\n" + url + "\n")
@@ -76,8 +118,10 @@ def get_soup(resp, log_errors=True):
     if not log_errors:
         return soup
 
-    errorbox = (soup.find(id="auth-error-message-box") or
-                soup.find(id="auth-warning-message-box"))
+    errorbox = (
+            soup.find(id="auth-error-message-box") or
+            soup.find(id="auth-warning-message-box")
+    )
     if errorbox:
         error_message = errorbox.find("h4").string.strip()
         for list_item in errorbox.findAll("li"):
@@ -92,10 +136,11 @@ def get_soup(resp, log_errors=True):
     return soup
 
 
-def get_inputs_from_soup(soup: BeautifulSoup,
-                         search_field: Optional[Dict[str, str]] = None
-                         ) -> Dict[str, str]:
+def get_inputs_from_soup(
+        soup: BeautifulSoup,
+        search_field: Optional[Dict[str, str]] = None) -> Dict[str, str]:
     """Extracts hidden form input fields from a Amazon login page."""
+
     search_field = search_field or {"name": "signIn"}
     form = soup.find("form", search_field) or soup.find("form")
     inputs = {}
@@ -109,6 +154,27 @@ def get_inputs_from_soup(soup: BeautifulSoup,
     return inputs
 
 
+def get_next_action_from_soup(
+        soup: BeautifulSoup, search_field: Optional[Dict[str, str]] = None
+) -> Tuple[str, str]:
+    search_field = search_field or {"name": "signIn"}
+    form = soup.find("form", search_field) or soup.find("form")
+    method = form.get("method", "GET")
+    url = form["action"]
+
+    return method, url
+    
+
+def create_code_verifier(length: int = 32) -> bytes:
+    verifier = secrets.token_bytes(length)
+    return base64.urlsafe_b64encode(verifier).rstrip(b'=')
+
+
+def create_s256_code_challenge(verifier: bytes):
+    m = hashlib.sha256(verifier)
+    return base64.urlsafe_b64encode(m.digest()).rstrip(b'=')
+
+
 def build_device_serial() -> str:
     return uuid.uuid4().hex.upper()
 
@@ -119,33 +185,39 @@ def build_client_id(serial: str) -> str:
 
 
 def build_oauth_url(
-    country_code: str,
-    domain: str,
-    market_place_id: str,
-    serial: Optional[str] = None,
-    with_username=False
-) -> Tuple[str, str]:
+        country_code: str,
+        domain: str,
+        market_place_id: str,
+        code_verifier: bytes,
+        serial: Optional[str] = None,
+        with_username=False) -> Tuple[str, str]:
     """Builds the url to login to Amazon as an Audible device"""
+
     if with_username and domain.lower() not in ("de", "com", "co.uk"):
-        raise ValueError("Login with username is only supported for DE, US "
-                         "and UK marketplaces!")
-        
+        raise ValueError(
+            "Login with username is only supported for DE, US "
+            "and UK marketplaces!"
+        )
+
     serial = serial or build_device_serial()
     client_id = build_client_id(serial)
+    code_challenge = create_s256_code_challenge(code_verifier)
+
+    base_url = f"https://www.amazon.{domain}/ap/signin"
+    return_to = f"https://www.amazon.{domain}/ap/maplanding"
+    assoc_handle = f"amzn_audible_ios_{country_code}"
+    page_id = "amzn_audible_ios"
 
     if with_username:
         base_url = f"https://www.audible.{domain}/ap/signin"
         return_to = f"https://www.audible.{domain}/ap/maplanding"
         assoc_handle = f"amzn_audible_ios_lap_{country_code}"
         page_id = "amzn_audible_ios_privatepool"
-    else:
-        base_url = f"https://www.amazon.{domain}/ap/signin"
-        return_to = f"https://www.amazon.{domain}/ap/maplanding"
-        assoc_handle = f"amzn_audible_ios_{country_code}"
-        page_id = "amzn_audible_ios"
 
     oauth_params = {
-        "openid.oa2.response_type": "token",
+        "openid.oa2.response_type": "code",
+        "openid.oa2.code_challenge_method": "S256",
+        "openid.oa2.code_challenge": code_challenge,
         "openid.return_to": return_to,
         "openid.assoc_handle": assoc_handle,
         "openid.identity": "http://specs.openid.net/auth/2.0/"
@@ -170,16 +242,17 @@ def build_oauth_url(
 
 def build_init_cookies() -> Dict[str, str]:
     """Build initial cookies to prevent captcha in most cases."""
+
     frc = secrets.token_bytes(313)
     frc = base64.b64encode(frc).decode("ascii").rstrip("=")
 
     map_md = {
         "device_user_dictionary": [],
         "device_registration_data": {
-            "software_version": "33501644"
+            "software_version": "35602678"
         },
         "app_identifier": {
-            "app_version": "3.35.1",
+            "app_version": "3.56.2",
             "bundle_id": "com.audible.iphone"
         }
     }
@@ -193,24 +266,28 @@ def build_init_cookies() -> Dict[str, str]:
 
 def check_for_captcha(soup: BeautifulSoup) -> bool:
     """Checks a Amazon login page for a captcha form."""
+
     captcha = soup.find("img", alt=lambda x: x and "CAPTCHA" in x)
     return True if captcha else False
 
 
 def extract_captcha_url(soup: BeautifulSoup) -> Optional[str]:
     """Returns the captcha url from a Amazon login page."""
+
     captcha = soup.find("img", alt=lambda x: x and "CAPTCHA" in x)
     return captcha["src"] if captcha else None
 
 
 def check_for_mfa(soup: BeautifulSoup) -> bool:
     """Checks a Amazon login page for a multi-factor authentication form."""
+
     mfa = soup.find("form", id=lambda x: x and "auth-mfa-form" in x)
     return True if mfa else False
 
 
 def check_for_choice_mfa(soup: BeautifulSoup) -> bool:
     """Checks a Amazon login page for a MFA selection form."""
+
     mfa_choice = soup.find("form", id="auth-select-device-form")
     return True if mfa_choice else False
 
@@ -222,22 +299,17 @@ def check_for_cvf(soup: BeautifulSoup) -> bool:
 
 def check_for_approval_alert(soup: BeautifulSoup) -> bool:
     """Checks a Amazon login page for an approval alert."""
-    approval_alert = soup.find("div", id="resend-approval-alert")
+
+    approval_alert = soup.find(id="resend-approval-alert") or soup.find(
+        id="resend-approval-form")
     return True if approval_alert else False
 
 
-def extract_cookies_from_session(session: httpx.Client) -> Dict[str, str]:
-    """Extracts cookies from a httpx Client."""
-    cookies = dict()
-    for cookie in session.cookies.jar:
-        cookies[cookie.name] = cookie.value.replace(r'"', r'')
-    return cookies
-
-
-def extract_token_from_url(url: httpx.URL) -> str:
+def extract_code_from_url(url: httpx.URL) -> str:
     """Extracts the access token from url query after login."""
+
     parsed_url = parse_qs(url.query.decode())
-    return parsed_url["openid.oa2.access_token"][0]
+    return parsed_url["openid.oa2.authorization_code"][0]
 
 
 def is_valid_email(obj: str) -> bool:
@@ -248,17 +320,17 @@ def is_valid_email(obj: str) -> bool:
 
 
 def login(
-    username: str,
-    password: str,
-    country_code: str,
-    domain: str,
-    market_place_id: str,
-    serial: Optional[str] = None,
-    with_username: bool = False,
-    captcha_callback: Optional[Callable[[str], str]] = None,
-    otp_callback: Optional[Callable[[], str]] = None,
-    cvf_callback: Optional[Callable[[], str]] = None,
-    approval_callback: Optional[Callable[[], Any]] = None
+        username: str,
+        password: str,
+        country_code: str,
+        domain: str,
+        market_place_id: str,
+        serial: Optional[str] = None,
+        with_username: bool = False,
+        captcha_callback: Optional[Callable[[str], str]] = None,
+        otp_callback: Optional[Callable[[], str]] = None,
+        cvf_callback: Optional[Callable[[], str]] = None,
+        approval_callback: Optional[Callable[[], Any]] = None
 ) -> Dict[str, Any]:
     """Login to Audible by simulating an Audible App for iOS.
     
@@ -282,23 +354,19 @@ def login(
             If ``None`` :func:`default_approval_alert_callback` is used.
     
     Returns:
-        An ``access_token`` with ``expires`` timestamp and the 
-        ``website_cookies`` from the authorized Client.
+        An ``authorization_code``, a ``code_verifier`` and the
+        ``device serial`` from the authorized Client.
     """
-    if not with_username and not is_valid_email(username):
-        logger.warning("Username %s is not a valid mail address." % username)
-    
+
     if with_username:
         base_url = f"https://www.audible.{domain}"
-        logger.info("Login with Audible username.")                    
+        logger.info("Login with Audible username.")
     else:
+        if not is_valid_email(username):
+            logger.warning(f"Username {username} is not a valid mail address.")
         base_url = f"https://www.amazon.{domain}"
         logger.info("Login with Amazon Account.")
 
-    sign_in_url = base_url + "/ap/signin"
-    cvf_url = base_url + "/ap/cvf/verify"
-    mfa_url = base_url + "/ap/mfa"
-
     default_headers = {
         "User-Agent": USER_AGENT,
         "Accept-Language": "en-US",
@@ -306,13 +374,22 @@ def login(
     }
     init_cookies = build_init_cookies()
 
-    session = httpx.Client(headers=default_headers, cookies=init_cookies)
+    session = httpx.Client(
+        base_url=base_url,
+        headers=default_headers,
+        cookies=init_cookies,
+        follow_redirects=True
+    )
+    code_verifier = create_code_verifier()
 
-    oauth_url, serial = build_oauth_url(country_code=country_code,
-                                        domain=domain,
-                                        market_place_id=market_place_id,
-                                        serial=serial,
-                                        with_username=with_username)
+    oauth_url, serial = build_oauth_url(
+        country_code=country_code,
+        domain=domain,
+        market_place_id=market_place_id,
+        code_verifier=code_verifier,
+        serial=serial,
+        with_username=with_username
+    )
 
     oauth_resp = session.get(oauth_url)
     oauth_soup = get_soup(oauth_resp)
@@ -324,7 +401,9 @@ def login(
     metadata = meta_audible_app(USER_AGENT, base_url)
     login_inputs["metadata1"] = encrypt_metadata(metadata)
 
-    login_resp = session.post(sign_in_url, data=login_inputs)
+    method, url = get_next_action_from_soup(oauth_soup, {"name": "signIn"})
+
+    login_resp = session.request(method, url, data=login_inputs)
     login_soup = get_soup(login_resp)
 
     # check for captcha
@@ -343,7 +422,9 @@ def login(
         inputs["email"] = username
         inputs["password"] = password
 
-        login_resp = session.post(sign_in_url, data=inputs)
+        method, url = get_next_action_from_soup(login_soup, {"name": "signIn"})
+
+        login_resp = session.request(method, url, data=inputs)
         login_soup = get_soup(login_resp)
 
     # check for choice mfa
@@ -358,7 +439,9 @@ def login(
                 inp_node = node.find("input")
                 inputs[inp_node["name"]] = inp_node["value"]
 
-        login_resp = session.post(mfa_url, data=inputs)
+        method, url = get_next_action_from_soup(login_soup)
+
+        login_resp = session.request(method, url, data=inputs)
         login_soup = get_soup(login_resp)
 
     # check for mfa (otp_code)
@@ -373,7 +456,9 @@ def login(
         inputs["mfaSubmit"] = "Submit"
         inputs["rememberDevice"] = "false"
 
-        login_resp = session.post(sign_in_url, data=inputs)
+        method, url = get_next_action_from_soup(login_soup)
+
+        login_resp = session.request(method, url, data=inputs)
         login_soup = get_soup(login_resp)
 
     # check for cvf
@@ -385,14 +470,18 @@ def login(
 
         inputs = get_inputs_from_soup(login_soup)
 
-        login_resp = session.post(cvf_url, data=inputs)
+        method, url = get_next_action_from_soup(login_soup)
+
+        login_resp = session.request(method, url, data=inputs)
         login_soup = get_soup(login_resp)
 
         inputs = get_inputs_from_soup(login_soup)
         inputs["action"] = "code"
         inputs["code"] = cvf_code
 
-        login_resp = session.post(cvf_url, data=inputs)
+        method, url = get_next_action_from_soup(login_soup)
+
+        login_resp = session.request(method, url, data=inputs)
         login_soup = get_soup(login_resp)
 
     # check for approval alert
@@ -402,37 +491,43 @@ def login(
         else:
             default_approval_alert_callback()
 
-        url = login_soup.find_all("a", class_="a-link-normal")[1]["href"]
+        # url = login_soup.find(id="resend-approval-link")["href"]
+        url = login_resp.url
 
         login_resp = session.get(url)
         login_soup = get_soup(login_resp)
 
+        while login_soup.find(
+                 "span", {"class": "transaction-approval-word-break"}
+         ):  # a-size-base-plus transaction-approval-word-break a-text-bold
+             login_resp = session.get(url)
+             login_soup = get_soup(login_resp)
+             logger.info("still waiting for redirect")
+
     session.close()
 
-    if not b"openid.oa2.access_token" in login_resp.url.query:
+    if b"openid.oa2.authorization_code" not in login_resp.url.query:
         raise Exception("Login failed. Please check the log.")
 
     logger.debug(f"Login confirmed for {username}")
 
-    access_token = extract_token_from_url(login_resp.url)
-    website_cookies = extract_cookies_from_session(session)
-    expires = (datetime.utcnow() + timedelta(seconds=3600)).timestamp()
+    authorization_code = extract_code_from_url(login_resp.url)
 
     return {
-        "access_token": access_token,
-        "website_cookies": website_cookies,
-        "expires": expires,
+        "authorization_code": authorization_code,
+        "code_verifier": code_verifier,
+        "domain": domain,
         "serial": serial
     }
 
 
 def external_login(
-    country_code: str,
-    domain: str,
-    market_place_id: str,
-    serial: Optional[str] = None,
-    with_username: bool = False,
-    login_url_callback: Optional[Callable[[str], str]] = None
+        country_code: str,
+        domain: str,
+        market_place_id: str,
+        serial: Optional[str] = None,
+        with_username: bool = False,
+        login_url_callback: Optional[Callable[[str], str]] = None
 ) -> Dict[str, Any]:
     """Gives the url to login with external browser and prompt for result.
 
@@ -453,14 +548,19 @@ def external_login(
             browsers. If ``None`` :func:`default_login_url_callback` is used.
 
     Returns:
-        An ``access_token`` with ``expires`` timestamp from the 
-        authorized Client.
+        An ``authorization_code``, a ``code_verifier`` and the
+        ``device serial`` from the authorized Client.
     """
-    oauth_url, serial = build_oauth_url(country_code=country_code,
-                                        domain=domain,
-                                        market_place_id=market_place_id,
-                                        serial=serial,
-                                        with_username=with_username)
+
+    code_verifier = create_code_verifier()
+    oauth_url, serial = build_oauth_url(
+        country_code=country_code,
+        domain=domain,
+        market_place_id=market_place_id,
+        code_verifier=code_verifier,
+        serial=serial,
+        with_username=with_username
+    )
 
     if login_url_callback:
         response_url = login_url_callback(oauth_url)
@@ -470,14 +570,11 @@ def external_login(
     response_url = httpx.URL(response_url)
     parsed_url = parse_qs(response_url.query.decode())
 
-    access_token = parsed_url["openid.oa2.access_token"][0]
-
-    auth_time = parsed_url["openid.pape.auth_time"][0]
-    auth_time = datetime.strptime(auth_time, "%Y-%m-%dT%H:%M:%SZ")
-    expires = (auth_time + timedelta(seconds=3600)).timestamp()
+    authorization_code = parsed_url["openid.oa2.authorization_code"][0]
 
     return {
-        "access_token": access_token,
-        "expires": expires,
+        "authorization_code": authorization_code,
+        "code_verifier": code_verifier,
+        "domain": domain,
         "serial": serial
     }
