@@ -13,17 +13,21 @@ logger = logging.getLogger("audible.utils")
 
 def _check_website_cookies(value: Dict[str, str]) -> None:
     if not isinstance(value, dict):
-        raise TypeError(f"website_cookies: Expected dict, "
-                        f"got {type(value).__name__}.")
+        raise TypeError(
+            f"website_cookies: Expected dict, "
+            f"got {type(value).__name__}."
+        )
     if not set(map(type, value.values())) == {str}:
-        raise TypeError("website_cookies: Value(s) of website_cookies have "
-                        "wrong type.")
+        raise TypeError(
+            "website_cookies: Value(s) of website_cookies have wrong type."
+        )
 
 
 def _check_adp_token(value: str) -> None:
     if not isinstance(value, str):
-        raise TypeError(f"adp_token: Expected str, "
-                        f"got {type(value).__name__}.")
+        raise TypeError(
+            f"adp_token: Expected str, got {type(value).__name__}."
+        )
 
     fmt = (r"^{enc:(?P<enc>.*?)}{key:(?P<key>.*?)}{iv:(?P<iv>.*?)}"
            r"{name:(?P<name>.*?)}{serial:(?P<serial>Mg==)}$")
@@ -33,8 +37,9 @@ def _check_adp_token(value: str) -> None:
 
 def _check_access_token(value: str) -> None:
     if not isinstance(value, str):
-        raise TypeError(f"access_token: Expected str, "
-                        f"got {type(value).__name__}.")
+        raise TypeError(
+            f"access_token: Expected str, got {type(value).__name__}."
+        )
 
     fmt = r"^(?P<access_token>Atna\|.*)$"
     if not re.match(fmt, value):
@@ -43,8 +48,9 @@ def _check_access_token(value: str) -> None:
 
 def _check_refresh_token(value: str) -> None:
     if not isinstance(value, str):
-        raise TypeError(f"refresh_token: Expected str, "
-                        f"got {type(value).__name__}.")
+        raise TypeError(
+            f"refresh_token: Expected str, got {type(value).__name__}."
+        )
 
     fmt = r"^(?P<refresh_token>Atnr\|.*)$"
     if not re.match(fmt, value):
@@ -53,8 +59,9 @@ def _check_refresh_token(value: str) -> None:
 
 def _check_device_private_key(value: str) -> None:
     if not isinstance(value, str):
-        raise TypeError(f"device_private_key: Expected str, "
-                        f"got {type(value).__name__}.")
+        raise TypeError(
+            f"device_private_key: Expected str, got {type(value).__name__}."
+        )
 
     fmt = (r"^(?P<device_private_key>-----BEGIN RSA PRIVATE KEY-----.*"
            r"-----END RSA PRIVATE KEY-----\n)$")
@@ -64,21 +71,23 @@ def _check_device_private_key(value: str) -> None:
 
 def _check_expires(value: Union[int, float, str]) -> Optional[float]:
     if not isinstance(value, (int, float, str)):
-        raise TypeError(f"expires: Expected int/float/str, "
-                        f"got {type(value).__name__}.")
+        raise TypeError(
+            f"expires: Expected int/float/str, got {type(value).__name__}.")
 
     if isinstance(value, str):
         try:
             return float(value)
         except ValueError as exc:
-            raise ValueError("expires: Got str. Converting to float "
-                             "raises an error.") from exc
+            raise ValueError(
+                "expires: Got str. Converting to float raises an error."
+            ) from exc
 
 
 def _check_locale(value: Union[str, Locale]) -> Optional[Locale]:
     if not isinstance(value, (Locale, str)):
-        raise TypeError(f"locales: Expected Locale/str, "
-                        f"got {type(value).__name__}.")
+        raise TypeError(
+            f"locales: Expected Locale/str, got {type(value).__name__}."
+        )
 
     if isinstance(value, str):
         return Locale(value.lower())
@@ -89,20 +98,24 @@ def _check_filename(value) -> pathlib.Path:
         try:
             return pathlib.Path(value)
         except Exception as exc:
-            raise Exception(f"filename: Got {type(value).__name__}. Converting "
-                            f"to Path raises an error.") from exc
+            raise Exception(
+                f"filename: Got {type(value).__name__}. Converting "
+                f"to Path raises an error."
+            ) from exc
 
 
 def _check_crypter(value: AESCipher) -> None:
     if not isinstance(value, AESCipher):
-        raise TypeError(f"crypter: Expected AESCipher, "
-                        f"got {type(value).__name__}.")
+        raise TypeError(
+            f"crypter: Expected AESCipher, got {type(value).__name__}."
+        )
 
 
 def _check_encryption(value: Union[bool, str]) -> None:
     if not isinstance(value, (bool, str)):
-        raise TypeError(f"encryption: Expected bool/str, "
-                        f"got {type(value).__name__}.")
+        raise TypeError(
+            f"encryption: Expected bool/str, got {type(value).__name__}."
+        )
 
     if value not in [False, "json", "bytes"]:
         raise ValueError("encryption: Value are not allowed.")
@@ -124,6 +137,7 @@ string_function_map = {
 
 def test_convert(key: str, value: Any) -> Any:
     """Helper function to check and convert values for specific keys."""
+
     if key in string_function_map and value is not None:
         return string_function_map[key](value) or value
 
@@ -136,3 +150,4 @@ class ElapsedTime:
 
     def __call__(self):
         return time.time() - self.start_time
+
